@@ -1,7 +1,7 @@
 #!/bin/sh
 ########################################################################
 #
-#   (c) 2001-2004 Intersect Alliance Pty Ltd
+#   (c) 2001-2006 Intersect Alliance Pty Ltd
 #
 #   This script controls the new audit daemon.
 #   Note that this script needs to be run before
@@ -43,11 +43,14 @@ case "$1" in
 		exit 1
 	fi
 
-	# Turn off auditing. This will also kill SNARE nicely.
-	/usr/sbin/auditconfig -setcond noaudit
+	# Turn off auditing. This will also kill SNARE nicely
+	# on solaris <= 9
+	/usr/sbin/auditconfig -setcond noaudit >/dev/null 2>&1
 	sleep 1
         PID=`cat /var/run/snarecore.pid 2>/dev/null`
        	if [ ! -z "$PID" ] ;  then
+		kill -USR1 ${PID}
+		sleep 1
 		kill ${PID}
 	fi
 	rm -f /var/run/snarecore.pid 2>/dev/null
